local AutoQuestTrackerFrame = CreateFrame("Frame")

AutoQuestTrackerFrame:RegisterEvent("ZONE_CHANGED")
AutoQuestTrackerFrame:RegisterEvent("ZONE_CHANGED_NEW_AREA")

local debug = false
local AQT_MESSAGE_PREFIX = "|cff2196F3Auto Quest Tracker: |r"

SLASH_AUTOQUESTTRACKER1 = "/autoquesttracker"
SLASH_AUTOQUESTTRACKER2 = "/aqt"
SlashCmdList["AUTOQUESTTRACKER"] = function(msg)
	if msg == "debug" then
		debug = not debug
		print(AQT_MESSAGE_PREFIX .. "Debug mode " .. (debug and "enabled" or "disabled"))
	else
		print(AQT_MESSAGE_PREFIX .. "Command not recognized. Available commands are: debug")
	end
end

function AQT_PrintDebugMsg(msg)
	if debug then
		print(AQT_MESSAGE_PREFIX .. msg);
	end
end

function AQT_HandleEvent(self, event, ...)
	-- Wait 2 seconds to reduce loading conjestion.
	C_Timer.After(2, function() AQT_UpdateQuestsForZone() end)
end

function AQT_UpdateQuestsForZone()
	local currentZone = GetRealZoneText()
	if currentZone == nil then
		return
	end

	AQT_PrintDebugMsg("Updating quests for current zone: " .. currentZone)

	local questZone = nil
	
	for questIndex = 1, GetNumQuestLogEntries() do
		local questTitle, _, _, isHeader, _, _, _, questId = GetQuestLogTitle(questIndex)
		
		if isHeader then
			questZone = questTitle
		else
			if not InCombatLockdown() then  -- Avoid tainting
				if questZone == currentZone then
					AQT_PrintDebugMsg(string.format("Tracking(Zone): %s (%s)", questTitle, questId))
					if not IsQuestWatched(questIndex) then
						AddQuestWatch(questIndex)
					end
				elseif IsQuestWatched(questIndex) and not IsQuestHardWatched(questIndex) then
					AQT_PrintDebugMsg(string.format("Removing(Zone): %s (%s)", questTitle, questId))
					RemoveQuestWatch(questIndex)
				end
			end
		end
	end
end


AutoQuestTrackerFrame:SetScript("OnEvent", AQT_HandleEvent)